@@ -30,7 +30,7 @@ extract_abs_sheets <- function(filename,
   sheets <- readxl::excel_sheets(path = filename)
   sheets <- sheets[!sheets %in% c(
     "Index", "Inquiries", "Enquiries",
-    "Contents"
+    "Contents", "Technical note", "Technical notes", "Note", "Notes"
   )]
   sheets <- sheets[!grepl("Table ", sheets, ignore.case = T)]
 
